package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbCooperatePartner;

import java.util.List;
import java.util.Map;

/**
 * 合作伙伴Service接口
 *
 * @author ruoyi
 * @date 2024-10-16
 */
public interface ITbCooperatePartnerService
{
    /**
     * 查询合作伙伴
     *
     * @param cooperatePartnerId 合作伙伴主键
     * @return 合作伙伴
     */
    public TbCooperatePartner selectTbCooperatePartnerByCooperatePartnerId(Long cooperatePartnerId);

    /**
     * 查询合作伙伴列表
     *
     * @param tbCooperatePartner 合作伙伴
     * @return 合作伙伴集合
     */
    public List<TbCooperatePartner> selectTbCooperatePartnerList(TbCooperatePartner tbCooperatePartner);

    /**
     * 新增合作伙伴
     *
     * @param tbCooperatePartner 合作伙伴
     * @return 结果
     */
    public int insertTbCooperatePartner(TbCooperatePartner tbCooperatePartner);

    /**
     * 修改合作伙伴
     *
     * @param tbCooperatePartner 合作伙伴
     * @return 结果
     */
    public int updateTbCooperatePartner(TbCooperatePartner tbCooperatePartner);

    /**
     * 批量删除合作伙伴
     *
     * @param cooperatePartnerIds 需要删除的合作伙伴主键集合
     * @return 结果
     */
    public int deleteTbCooperatePartnerByCooperatePartnerIds(Long[] cooperatePartnerIds);

    /**
     * 删除合作伙伴信息
     *
     * @param cooperatePartnerId 合作伙伴主键
     * @return 结果
     */
    public int deleteTbCooperatePartnerByCooperatePartnerId(Long cooperatePartnerId);

    /**
     * 合作伙伴列表
     *
     * @param params 参数
     * @return 合作伙伴列表
     */
    public List<Map<String, Object>> getCooperatePartnerList(Map<String, Object> params);
}
